MAICoS Documentation
====================

This documentation covers everything you need to know about MAICoS, the Molecular
Analysis for Interfacial and Confined Systems toolkit. There are five sections:

- :ref:`userdoc-get-started`
- :ref:`userdoc-how-to`
- :ref:`userdoc-analysis-modules`
- :ref:`userdoc_api-documentation`
- :ref:`userdoc-concepts-explanations`
- :ref:`devdoc`

If you are new to MAICoS, we recommend starting with the :ref:`userdoc-get-started`
section. If you want to contribute to the development of the library, please have a look
at our :ref:`developer documentation <devdoc>`.

Getting started
---------------
The :ref:`userdoc-get-started` section is for MAICoS beginners. It will help you install
and familiarize yourself with MAICoS and its approach to analyse molecular dynamics
simulations.

How-to guides
-------------
The :ref:`userdoc-how-to` section is for MAICoS intermediate and advanced users. It
contains guides taking you through series of steps involved in addressing key problems
and special use-cases in MAICoS.

Analysis Modules
----------------
The :ref:`userdoc-analysis-modules` section is for MAICoS for intermediate users, it
contains technical references and parameter list for each MAICoS module. Even more
advanced API documentation of all underlying *functions* and *classes* is described in
:ref:`userdoc_api-documentation`.

API Documentation
-----------------
The :ref:`userdoc_api-documentation` section is for MAICoS for advanced users, it
contains technical references and parameter list for the APIs behind the library. It
describes the various functionalities provided by MAICoS. You can always refer to this
section to learn more about classes, functions, modules, and other aspects of MAICoS
machinery you may come across behind the analysis classes described in
:ref:`userdoc-analysis-modules`.

Concepts & Explanations
-----------------------
The :ref:`userdoc-concepts-explanations` section discusses key topics and concepts at a
fairly high level and provides explanations to expand your knowledge of MAICoS. It
requires at least basic to intermediate knowledge of MAICoS.

Developer documentation
-----------------------
The :ref:`devdoc` helps you contributing to the code base or the documentation of
MAICoS.

.. toctree::
   :hidden:

   get-started/index
   examples/index
   analysis-modules/index
   api-documentation/index
   concepts-explanations/index
   devdoc/index
   contributors
